@@ -33,6 +33,9 @@ pub enum WorkflowError {
     #[error(transparent)]
     CascadeError(#[from] CascadeError),
 
+    #[error(transparent)]
+    CounterSigningError(#[from] CounterSigningError),
+
     #[error("Workspace error: {0}")]
     WorkspaceError(#[from] WorkspaceError),
 
@@ -66,6 +69,9 @@ pub enum WorkflowError {
     #[error(transparent)]
     HoloHashError(#[from] holo_hash::error::HoloHashError),
 
+    #[error(transparent)]
+    InterfaceError(#[from] crate::conductor::interface::error::InterfaceError),
+
     #[error(transparent)]
     DhtOpError(#[from] DhtOpError),
 
